==> lxqt-l10n-0.12.0.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-desktopswitch/desktopswitch_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../../../desktopswitch.cpp" line="84"/>
        <source>Switch to desktop %1</source>
        <translation type="unfinished">デスクトップ%1に切り替える</translation>
    </message>
    <message>
        <location filename="../../../desktopswitch.cpp" line="141"/>
        <location filename="../../../desktopswitch.cpp" line="151"/>
        <source>Desktop %1</source>
        <translation>デスクトップ %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchButton</name>
    <message>
        <source>Switch to desktop %1</source>
        <translation type="vanished">デスクトップ%1に切り替える</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="70"/>
        <source>Desktop names</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-desktopswitch/desktopswitch_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>DesktopSwitch</name>
    <message>
        <location filename="../../../desktopswitch.cpp" line="84"/>
        <source>Switch to desktop %1</source>
        <translation>デスクトップ%1に切り替える</translation>
    </message>
    <message>
        <location filename="../../../desktopswitch.cpp" line="141"/>
        <location filename="../../../desktopswitch.cpp" line="151"/>
        <source>Desktop %1</source>
        <translation>デスクトップ %1</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchButton</name>
    <message>
        <source>Switch to desktop %1</source>
        <translation type="vanished">デスクトップ%1に切り替える</translation>
    </message>
</context>
<context>
    <name>DesktopSwitchConfiguration</name>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="14"/>
        <source>DesktopSwitch settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="46"/>
        <source>Number of rows:</source>
        <translation>段の数:</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="39"/>
        <source>Desktop labels:</source>
        <translation>デスクトップのラベル:</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="54"/>
        <source>Numbers</source>
        <translation>番号</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="59"/>
        <source>Names</source>
        <translation>名前</translation>
    </message>
    <message>
        <location filename="../../../desktopswitchconfiguration.ui" line="70"/>
        <source>Desktop names</source>
        <translation>デスクトップの名前</translation>
    </message>
</context>
</TS>
